import _cloneDeep from 'lodash/cloneDeep';
import { useCallback, useImperativeHandle, useRef } from 'react';

/**
 * 父调用子组件方法，并传值更新状态
 * @param funcRef ref对象
 * @param options { onShow, onFormart, onHide }
 * @returns T 传输的数据
 */
export default function useShow(funcRef, options) {
  var ref = useRef(null);
  var childrenDataRef = useRef(null);
  var opsOnShow = options.onShow,
      opsOnFormart = options.onFormart,
      opsOnHide = options.onHide;
  var onCallback = useCallback(function (data) {
    childrenDataRef.current = data;
  }, []);
  useImperativeHandle(funcRef, function () {
    return {
      onShow: function onShow(data) {
        ref.current = _cloneDeep(data);
        if (opsOnShow) opsOnShow(ref.current);
      },
      onHide: function onHide(data) {
        if (opsOnHide) opsOnHide(_cloneDeep(data));
      },
      getChildData: function getChildData() {
        // 传给父组件的数据
        return childrenDataRef.current;
      }
    };
  });
  return {
    parentData: opsOnFormart ? opsOnFormart(ref.current) : ref.current,
    setParentData: onCallback
  };
}