"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = useConcurrentRequest;

var _react = require("react");

/**
 * 并发请求函数
 * @param {*} asyncFns
 * @param {*} max
 * @return {*}
 */
function useConcurrentRequest(asyncFns, max = 3) {
  const [loading, setLoading] = (0, _react.useState)(false);
  const run = (0, _react.useCallback)(() => {
    return new Promise((resolve, reject) => {
      if (asyncFns.length === 0) {
        resolve([]);
        return;
      }

      const result = [];
      let index = 0,
          // 获取当前异步函数的索引
      count = 0; // 请求次数

      async function request() {
        if (index === asyncFns.length) return;
        const i = index,
              curFn = asyncFns[index];
        index++;

        try {
          setLoading(true);
          const ret = await curFn();
          result[i] = ret;
        } catch (err) {
          result[i] = err;
          reject(err);
        } finally {
          count++;

          if (count === asyncFns.length) {
            setLoading(false);
            resolve(result);
          }

          request();
        }
      }

      const num = Math.min(max, asyncFns.length);

      for (let s = 0; s < num; s++) {
        request();
      }
    }); // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);
  return {
    run,
    loading
  };
}